==> traccar_api_python_client-0.0.2-py3-none-any.whl: traccar_api_client/models/calendar.py <==
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.calendar_attributes import CalendarAttributes


T = TypeVar("T", bound="Calendar")


@_attrs_define
class Calendar:
    """
    Attributes:
        id (int | Unset):
        name (str | Unset):
        data (str | Unset): base64 encoded in iCalendar format
        attributes (CalendarAttributes | Unset):
    """

    id: int | Unset = UNSET
    name: str | Unset = UNSET
    data: str | Unset = UNSET
    attributes: CalendarAttributes | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        id = self.id

        name = self.name

        data = self.data

        attributes: dict[str, Any] | Unset = UNSET
        if not isinstance(self.attributes, Unset):
            attributes = self.attributes.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if name is not UNSET:
            field_dict["name"] = name
        if data is not UNSET:
            field_dict["data"] = data
        if attributes is not UNSET:
            field_dict["attributes"] = attributes

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.calendar_attributes import CalendarAttributes

        d = dict(src_dict)
        id = d.pop("id", UNSET)

        name = d.pop("name", UNSET)

        data = d.pop("data", UNSET)

        _attributes = d.pop("attributes", UNSET)
        attributes: CalendarAttributes | Unset
        if isinstance(_attributes, Unset):
            attributes = UNSET
        else:
            attributes = CalendarAttributes.from_dict(_attributes)

        calendar = cls(
            id=id,
            name=name,
            data=data,
            attributes=attributes,
        )

        calendar.additional_properties = d
        return calendar

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> traccar_api_python_client-0.0.3-py3-none-any.whl: traccar_api_client/models/calendar.py <==
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.calendar_attributes import CalendarAttributes


T = TypeVar("T", bound="Calendar")


@_attrs_define
class Calendar:
    """
    Attributes:
        id (int | Unset):
        name (str | Unset):
        data (str | Unset): base64 encoded in iCalendar format
        attributes (CalendarAttributes | Unset):
    """

    id: int | Unset = UNSET
    name: str | Unset = UNSET
    data: str | Unset = UNSET
    attributes: CalendarAttributes | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        id = self.id

        name = self.name

        data = self.data

        attributes: dict[str, Any] | Unset = UNSET
        if not isinstance(self.attributes, Unset):
            attributes = self.attributes.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if name is not UNSET:
            field_dict["name"] = name
        if data is not UNSET:
            field_dict["data"] = data
        if attributes is not UNSET:
            field_dict["attributes"] = attributes

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.calendar_attributes import CalendarAttributes

        d = dict(src_dict)
        id = d.pop("id", UNSET)

        name = d.pop("name", UNSET)

        data = d.pop("data", UNSET)

        _attributes = d.pop("attributes", UNSET)
        attributes: CalendarAttributes | Unset
        if isinstance(_attributes, Unset) or _attributes is None:
            attributes = UNSET
        else:
            attributes = CalendarAttributes.from_dict(_attributes)

        calendar = cls(
            id=id,
            name=name,
            data=data,
            attributes=attributes,
        )

        calendar.additional_properties = d
        return calendar

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
